# td-ml-probabilistic-unification

## Introduction
Python package for Probabilistic Unification

##### Declare ENV Variables from YML file
- **apikey** = os.environ['TD_API_KEY']
- **tdserver** = os.environ['TD_API_SERVER']
- **sink_database** = os.environ['SINK_DB']
- **output_table** = os.environ['OUTPUT_TABLE

#####----Defining Variables-------#####



## Expected Input Table


`Copyright © 2022 Treasure Data, Inc. (or its affiliates). All rights reserved`
